# geodemo_zw


[![image](https://img.shields.io/pypi/v/geodemo_zw.svg)](https://pypi.python.org/pypi/geodemo_zw)
[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://gishub.org/geodemo_ZW-colab)
[![image](https://binder.pangeo.io/badge_logo.svg)](https://binder.pangeo.io/v2/gh/giswqs/geodemo_ZW/master)
[![image](https://img.shields.io/conda/vn/conda-forge/geodemo_ZW.svg)](https://anaconda.org/conda-forge/geodemo_ZW)
[![image](https://pepy.tech/badge/geodemo_ZW)](https://pepy.tech/project/geodemo_ZW)
[![image](https://github.com/giswqs/geodemo_ZW/workflows/docs/badge.svg)](https://geodemo_ZW.org)
[![image](https://github.com/giswqs/geodemo_ZW/workflows/build/badge.svg)](https://github.com/giswqs/geodemo_ZW/actions?query=workflow%3Abuild)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/giswqs/geodemo_ZW.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/giswqs/geodemo_ZW/context:python)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

**A geodeom from remote desktop**


-   Free software: MIT license
-   Documentation: https://DataGeoranger.github.io/geodemo_zw
    

## Features

-   TODO
-   TODO 2

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
